==> huaweicloudsdksdrs-3.0.80-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/create_replication_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateReplicationRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'replication': 'CreateReplicationRequestParams'
    }

    attribute_map = {
        'replication': 'replication'
    }

    def __init__(self, replication=None):
        """CreateReplicationRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._replication = None
        self.discriminator = None

        self.replication = replication

    @property
    def replication(self):
        """Gets the replication of this CreateReplicationRequestBody.


        :return: The replication of this CreateReplicationRequestBody.
        :rtype: CreateReplicationRequestParams
        """
        return self._replication

    @replication.setter
    def replication(self, replication):
        """Sets the replication of this CreateReplicationRequestBody.


        :param replication: The replication of this CreateReplicationRequestBody.
        :type: CreateReplicationRequestParams
        """
        self._replication = replication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateReplicationRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksdrs-3.0.95-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/create_replication_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateReplicationRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'replication': 'CreateReplicationRequestParams'
    }

    attribute_map = {
        'replication': 'replication'
    }

    def __init__(self, replication=None):
        """CreateReplicationRequestBody

        The model defined in huaweicloud sdk

        :param replication: 
        :type replication: :class:`huaweicloudsdksdrs.v1.CreateReplicationRequestParams`
        """
        
        

        self._replication = None
        self.discriminator = None

        self.replication = replication

    @property
    def replication(self):
        """Gets the replication of this CreateReplicationRequestBody.


        :return: The replication of this CreateReplicationRequestBody.
        :rtype: :class:`huaweicloudsdksdrs.v1.CreateReplicationRequestParams`
        """
        return self._replication

    @replication.setter
    def replication(self, replication):
        """Sets the replication of this CreateReplicationRequestBody.


        :param replication: The replication of this CreateReplicationRequestBody.
        :type replication: :class:`huaweicloudsdksdrs.v1.CreateReplicationRequestParams`
        """
        self._replication = replication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateReplicationRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
